@@ -113,6 +113,7 @@ ON_OFF_CAPABILITIES = create_with_capabilities(
 
 GOVEE_LIGHT_CAPABILITIES: dict[str, GoveeLightCapabilities] = {
     # Models with common features
+    "H6008": BASIC_CAPABILITIES,
     "H600D": BASIC_CAPABILITIES,
     "H6022": BASIC_CAPABILITIES,
     "H6042": create_with_capabilities(True, True, True, 5, True),
@@ -122,6 +123,7 @@ GOVEE_LIGHT_CAPABILITIES: dict[str, GoveeLightCapabilities] = {
     "H6052": BASIC_CAPABILITIES,
     "H6056": BASIC_CAPABILITIES,
     "H6059": BASIC_CAPABILITIES,
+    "H605D": BASIC_CAPABILITIES,
     "H6061": BASIC_CAPABILITIES,
     "H6062": BASIC_CAPABILITIES,
     "H6065": BASIC_CAPABILITIES,
@@ -146,6 +148,7 @@ GOVEE_LIGHT_CAPABILITIES: dict[str, GoveeLightCapabilities] = {
     "H6110": BASIC_CAPABILITIES,
     "H6117": BASIC_CAPABILITIES,
     "H612A": BASIC_CAPABILITIES,
+    "H612B": BASIC_CAPABILITIES,
     "H612F": create_with_capabilities(True, True, True, 5, True),
     "H6144": BASIC_CAPABILITIES,
     "H6159": BASIC_CAPABILITIES,
@@ -155,6 +158,7 @@ GOVEE_LIGHT_CAPABILITIES: dict[str, GoveeLightCapabilities] = {
     "H615D": create_with_capabilities(True, True, True, 0, True),
     "H615E": create_with_capabilities(True, True, True, 0, True),
     "H6163": BASIC_CAPABILITIES,
+    "H6167": BASIC_CAPABILITIES,
     "H6168": BASIC_CAPABILITIES,
     "H6172": BASIC_CAPABILITIES,
     "H6173": BASIC_CAPABILITIES,
@@ -177,19 +181,22 @@ GOVEE_LIGHT_CAPABILITIES: dict[str, GoveeLightCapabilities] = {
     "H61A5": BASIC_CAPABILITIES,
     "H61A8": BASIC_CAPABILITIES,
     "H61B2": BASIC_CAPABILITIES,
+    "H61B3": create_with_capabilities(True, True, True, 15, True),
     "H61B5": BASIC_CAPABILITIES,
     "H61BA": BASIC_CAPABILITIES,
     "H61BE": BASIC_CAPABILITIES,
     "H61BC": BASIC_CAPABILITIES,
+    "H61C2": BASIC_CAPABILITIES,
     "H61C5": BASIC_CAPABILITIES,
     "H61C3": BASIC_CAPABILITIES,
     "H61D3": BASIC_CAPABILITIES,
     "H61D5": BASIC_CAPABILITIES,
     "H61E0": BASIC_CAPABILITIES,
     "H61E1": BASIC_CAPABILITIES,
-    "H61E5": BASIC_CAPABILITIES,
+    "H61E5": create_with_capabilities(True, True, True, 12, True),
     "H61E6": create_with_capabilities(True, True, True, 15, True),
     "H61F5": BASIC_CAPABILITIES,
+    "H6609": create_with_capabilities(True, True, True, 18, True),
     "H6640": create_with_capabilities(True, True, True, 8, True),
     "H6641": create_with_capabilities(True, True, True, 14, True),
     "H7012": create_with_capabilities(False, False, True, 0, False),
@@ -235,4 +242,5 @@ GOVEE_LIGHT_CAPABILITIES: dict[str, GoveeLightCapabilities] = {
     "H70BC": BASIC_CAPABILITIES,
     "H70D1": BASIC_CAPABILITIES,
     "H805C": BASIC_CAPABILITIES,
+    "H8072": create_with_capabilities(True, True, True, 8, True),
 }
